#[unsafe(no_mangle)]pub unsafe extern "C" fn read_dora_input_timestamp(
event: *const (),
) -> c_ulonglongExpand description
Reads out the timestamp of the given input event from metadata.
Returns 0 if the given event is not an input event.
Safety
The event argument must be a dora event received through
dora_next_event. The event must be still valid, i.e., not
freed yet.